@@ -45,7 +45,10 @@ def _get_versionhash():
 def _get_cachedir():
     if 'GI_SCANNER_DISABLE_CACHE' in os.environ:
         return None
-    homedir = os.environ.get('HOME')
+    if os.name == 'nt' and 'MSYSTEM' not in os.environ:
+        homedir = os.environ.get('HOMEPATH')
+    else:
+        homedir = os.environ.get('HOME')
     if homedir is None:
         return None
     if not os.path.exists(homedir):
